@@ -1169,6 +1169,8 @@ static gboolean _browse_playlists_branch(const gchar *playlist,
 		}
 
 		ti_get_playlists(bc->metadata_keys,
+				 bc->filter_criteria,
+				 bc->sort_fields,
 				 bc->offset,
 				 bc->count,
 				 _browse_playlists_tracker_cb,
